Implement the current task using the default subagent workflow.

Steps:
1. Read `.agent/STATE.md`, `.agent/project_profile.yaml`, and the relevant workflow in `.agent/workflows/`.
2. Ask the `implementer` subagent to make the change.
3. Ask the `reviewer` subagent to review the result and verification.
